==> cavity-5.2.tar.gz: cavity-5.2/src/cavini.c <==
/* -*- C -*- */

#include "cavity.h"

/*****************************************************
c      subroutine setmin
c
c     Setup Range Minimum/Maximum
c
*****************************************************/

static void setmin(void){
  int i,j;
  for(i=0;i<3;i++){
    cmin[i]=cmax[i]=xyz[iExcl[0]][i];
  }
  for(i=0;i<3;i++){
    for(j=0;j<nExcl;j++){
      double t=xyz[iExcl[j]][i];
      if (t<cmin[i]) cmin[i]=t;
      if (t>cmax[i]) cmax[i]=t;
    }
    cmin[i]-=cAdd;
    cmax[i]+=cAdd;
  }
  for(i=0;i<nExcl;i++){
    fprintf(stderr,"%d / %d\n",iExcl[i],nExcl);
  }
}

int CavInit(void) {
  int i,j,k,l;

  if (GlobalInit()==0){
    fprintf(stderr,"Can't allocate memory!\n");
    exit(1);
  };

  l_log=fopen("cav.log","w");
  if (l_log==NULL) error("Can't Open Log File!");
  iErr=0;

  for(i=0;i<=360;i++){
    sint[i]=sin(dtor(i));
    cost[i]=cos(dtor(i));
  }
  for(i=0;i<MaxAtm;i++){
    iUse[i]=0;
    bExclFlag[i]=0;
  }

  if (!ReadControlFile("cav.cnt")) error("Can't Open Control File!");
  if (!ReadDataFile("cav.dat")) error("Can't Open Data File!");
  if (!CleanStructure()) error("Memory error!");

  if (!CavOpenPlotter("cav.ps")) error("Can't Open Output File!");

  for(i=0;i<nAtom;i++){
    w[i]=Vdw[iTbl[i]-1];
    w2[i]=w[i]*w[i];
  }
  for(i=0;i<nPlt;i++){
    l=iPlt[i];
    for(j=0;j<nExcl;j++){
      k=iExcl[j];
      if (l!=k) {
	double dx,dy,dz,dist;
	dx=xyz[l][0]-xyz[k][0];
	dy=xyz[l][1]-xyz[k][1];
	dz=xyz[l][2]-xyz[k][2];
	dist=dx*dx+dy*dy+dz*dz;
	if (w2[l]>dist) w2[l]=dist;
      }
      w[l]=sqrt(w2[l]);
    }
  }
  for(i=0;i<nAtom;i++){
    fprintf(l_log,"%-6s%4d%10.6f%10.6f%10.6f%10.6f\n",natm[i],i+1,
	    xyz[i][0],xyz[i][1],xyz[i][2],w[i]);
  }
  if (divz<0) divz=0.2;
  fflush(l_log);
  return 1;
}

/****************************************************************
c     initialize2
c     set initial range, axis
****************************************************************/

void cavin2(void){
  int i;
  switch(iView){
  case 1:
    kx=1;
    ky=2;
    kz=0;
    break;
  case 2:
    kx=2;
    ky=0;
    kz=1;
    break;
  case 3:
  default:
    kx=0;
    ky=1;
    kz=2;
    break;
  }
  if (nInt==0) {
    setmin();
  } 
  xmin=cmin[kx];
  xmax=cmax[kx];
  ymin=cmin[ky];
  ymax=cmax[ky];
  zmin=cmin[kz];
  zmax=cmax[kz];
  fprintf(l_log,"# Initial Range\n# %10.6f%10.6f%10.6f%10.6f%10.6f%10.6f%10.6f\n",
	  cmin[0],cmax[0],cmin[1],cmax[1],cmin[2],cmax[2],divz);
  for(i=0;i<3;i++){
    cmin[i]=10000;
    cmax[i]=-10000;
  }
}

/********************************************************
      subroutine used
********************************************************/
void used(void){
  int i;
  for(i=0;i<nAtom;i++){
    if (iUse[i]){
      fprintf(l_log,"%-2s%4d%10.6f%10.6f%10.6f%10.6f\n",natm[i],i,
	      xyz[i][0],xyz[i][1],xyz[i][2],w[i]);
    }
  }
  fprintf(l_log,"#\n");
  for(i=0;i<nAtom;i++){
    if (iUse[i]==2){
      fprintf(l_log,"%-2s%4d%10.6f%10.6f%10.6f%10.6f\n",natm[i],i,
	      xyz[i][0],xyz[i][1],xyz[i][2],w[i]);
    }
  }
}

/*****************************************************************
c
c     Cavity Final Message Print Routine
c     (Range, Step, Volume Print Out)
c
*****************************************************************/

int CavTrailer(void){
  int i;
  for(i=0;i<3;i++){
    cmin[i]-=2*divz;
    cmax[i]+=2*divz;
  }
  if (cmin[kx]<xmin || nInt!=0) cmin[kx]=xmin;
  if (cmax[kx]>xmax || nInt!=0) cmax[kx]=xmax;
  if (cmin[ky]<ymin || nInt!=0) cmin[ky]=ymin;
  if (cmax[ky]>ymax || nInt!=0) cmax[ky]=ymax;
  if (cmin[kz]<zmin || nInt!=0) cmin[kz]=zmin;
  if (cmax[kz]>zmax || nInt!=0) cmax[kz]=zmax;
  fprintf(l_log,"$ Range\n");
  fprintf(l_log,"     XMIN,     XMAX,     YMIN,     YMAX,"
	  "     ZMIN,     ZMAX,     DIV\n");
  fprintf(l_log,"%10.4f%10.4f%10.4f%10.4f%10.4f%10.4f%10.4f\n",
	  cmin[0],cmax[0],cmin[1],cmax[1],cmin[2],cmax[2],divz);
  sprintf(lbuf,"XRANGE = %10.4f%10.4f",cmin[0],cmax[0]);
  CavPlotComment(lbuf);
  sprintf(lbuf,"YRANGE = %10.4f%10.4f",cmin[1],cmax[1]);
  CavPlotComment(lbuf);
  sprintf(lbuf,"ZRANGE = %10.4f%10.4f",cmin[2],cmax[2]);
  CavPlotComment(lbuf);
  if (iErr==0){
    if (iVol!=0){
      fprintf(l_log,"Volume =  %10.3f\n",vol);
      sprintf(lbuf,"Volume = %8.3f",vol);
      CavPlotComment(lbuf);
    } else {
      fprintf(l_log,"Volume =  %10.3f\n",-1.0);
    }
  } else {
    sprintf(lbuf,"Cavity Calculation Error\n");
    CavPlotComment(lbuf);
  }
  fflush(l_log);
  fprintf(l_log,"$ CavAtom\n");
  used();
  fflush(l_log);
  fprintf(l_log,"$ PlotAtom\n");
  for(i=0;i<nPlt;i++){
    int k;
    k=iPlt[i];
    fprintf(l_log,"%-6s%4d%10.5f%10.5f%10.5f%10.5f\n",natm[k],iTbl[k],
	    xyz[k][0],xyz[k][1],xyz[k][2],w[k]);
  }
  fflush(l_log);
  fprintf(l_log,"$ CavBond\n");
  for(i=0;i<nBond;i++){
    double *sxyz,*exyz;
    sxyz=xyz[iPs[i]];
    exyz=xyz[iPe[i]];
    fprintf(l_log,"%-6s %10.5f%10.5f%10.5f %-6s %10.5f%10.5f%10.5f \n",
	    natm[iPs[i]],sxyz[0],sxyz[1],sxyz[2],
	    natm[iPe[i]],exyz[0],exyz[1],exyz[2]);
  }
  fprintf(l_log,"$ End\n");
  fflush(l_log);
  CavClosePlotter();
  fclose(l_log);
  return 1;
}

==> cavity-5.4.tar.gz: cavity-5.4/src/cavini.c <==
/* -*- C -*- */

#include "cavity.h"
#include <stdlib.h>

/*****************************************************
c      subroutine setmin
c
c     Setup Range Minimum/Maximum
c
*****************************************************/

static void setmin(void){
  int i,j;
  for(i=0;i<3;i++){
    cmin[i]=cmax[i]=xyz[iExcl[0]][i];
  }
  for(j=1;j<nExcl;j++){
    for(i=0;i<3;i++){
      double t=xyz[iExcl[j]][i];
      if (t<cmin[i]) cmin[i]=t;
      if (t>cmax[i]) cmax[i]=t;
    }
  }
  for(i=0;i<3;i++){
    cmin[i]-=cAdd;
    cmax[i]+=cAdd;
  }
}

int CavInit(void) {
  int i,j,k,l;

  if (GlobalInit()==0){
    fprintf(stderr,"Can't allocate memory!\n");
    exit(1);
  };

  l_log=fopen("cav.log","w");
  if (l_log==NULL) error("Can't Open Log File!");
  iErr=0;

  for(i=0;i<=360;i++){
    sint[i]=sin(dtor(i));
    cost[i]=cos(dtor(i));
  }
  for(i=0;i<MaxAtm;i++){
    iUse[i]=0;
    bExclFlag[i]=0;
  }

  if (!ReadControlFile("cav.cnt")) error("Can't Open Control File 'cav.cnt'!");
  if (!ReadDataFile("cav.dat")) error("Can't Open Data File 'cav.dat'!");
  if (!CleanStructure()) error("Memory error!");

  if (!CavOpenPlotter("cav.ps")) error("Can't Open Output File 'cav.ps'!");

  for(i=0;i<nAtom;i++){
    w[i]=Vdw[iTbl[i]-1];
    w2[i]=w[i]*w[i];
  }
  for(i=0;i<nPlt;i++){
    l=iPlt[i];
    for(j=0;j<nExcl;j++){
      k=iExcl[j];
      if (l!=k) {
	double dx,dy,dz,dist;
	dx=xyz[l][0]-xyz[k][0];
	dy=xyz[l][1]-xyz[k][1];
	dz=xyz[l][2]-xyz[k][2];
	dist=dx*dx+dy*dy+dz*dz;
	if (w2[l]>dist) w2[l]=dist;
      }
      w[l]=sqrt(w2[l]);
    }
  }
  for(i=0;i<nAtom;i++){
    fprintf(l_log,"%-6s%4d%10.6f%10.6f%10.6f%10.6f\n",natm[i],i+1,
	    xyz[i][0],xyz[i][1],xyz[i][2],w[i]);
  }
  if (divz<0) divz=0.2;
  fflush(l_log);
  return 1;
}

/****************************************************************
c     initialize2
c     set initial range, axis
****************************************************************/

void cavin2(void){
  int i;
  switch(iView){
  case 1:
    kx=1;
    ky=2;
    kz=0;
    break;
  case 2:
    kx=2;
    ky=0;
    kz=1;
    break;
  case 3:
  default:
    kx=0;
    ky=1;
    kz=2;
    break;
  }
  if (nInt==0) {
    setmin();
  } 
  xmin=cmin[kx];
  xmax=cmax[kx];
  ymin=cmin[ky];
  ymax=cmax[ky];
  zmin=cmin[kz];
  zmax=cmax[kz];
  fprintf(l_log,"# Initial Range\n# %10.6f%10.6f%10.6f%10.6f%10.6f%10.6f%10.6f\n",
	  cmin[0],cmax[0],cmin[1],cmax[1],cmin[2],cmax[2],divz);
  for(i=0;i<3;i++){
    cmin[i]=10000;
    cmax[i]=-10000;
  }
}

/********************************************************
      subroutine used
********************************************************/
void used(void){
  int i;
  for(i=0;i<nAtom;i++){
    if (iUse[i]){
      fprintf(l_log,"%-2s%4d%10.6f%10.6f%10.6f%10.6f\n",natm[i],i,
	      xyz[i][0],xyz[i][1],xyz[i][2],w[i]);
    }
  }
  fprintf(l_log,"#\n");
  for(i=0;i<nAtom;i++){
    if (iUse[i]==2){
      fprintf(l_log,"%-2s%4d%10.6f%10.6f%10.6f%10.6f\n",natm[i],i,
	      xyz[i][0],xyz[i][1],xyz[i][2],w[i]);
    }
  }
}

/*****************************************************************
c
c     Cavity Final Message Print Routine
c     (Range, Step, Volume Print Out)
c
*****************************************************************/

int CavTrailer(void){
  int i;
  for(i=0;i<3;i++){
    cmin[i]-=2*divz;
    cmax[i]+=2*divz;
  }
  if (cmin[kx]<xmin || nInt!=0) cmin[kx]=xmin;
  if (cmax[kx]>xmax || nInt!=0) cmax[kx]=xmax;
  if (cmin[ky]<ymin || nInt!=0) cmin[ky]=ymin;
  if (cmax[ky]>ymax || nInt!=0) cmax[ky]=ymax;
  if (cmin[kz]<zmin || nInt!=0) cmin[kz]=zmin;
  if (cmax[kz]>zmax || nInt!=0) cmax[kz]=zmax;
  fprintf(l_log,"$ Range\n");
  fprintf(l_log,"     XMIN,     XMAX,     YMIN,     YMAX,"
	  "     ZMIN,     ZMAX,     DIV\n");
  fprintf(l_log,"%10.4f%10.4f%10.4f%10.4f%10.4f%10.4f%10.4f\n",
	  cmin[0],cmax[0],cmin[1],cmax[1],cmin[2],cmax[2],divz);
  sprintf(lbuf,"XRANGE = %10.4f%10.4f",cmin[0],cmax[0]);
  CavPlotComment(lbuf);
  sprintf(lbuf,"YRANGE = %10.4f%10.4f",cmin[1],cmax[1]);
  CavPlotComment(lbuf);
  sprintf(lbuf,"ZRANGE = %10.4f%10.4f",cmin[2],cmax[2]);
  CavPlotComment(lbuf);
  if (iErr==0){
    if (iVol!=0){
      fprintf(l_log,"Volume =  %10.3f\n",vol);
      sprintf(lbuf,"Volume = %8.3f",vol);
      CavPlotComment(lbuf);
    } else {
      fprintf(l_log,"Volume =  %10.3f\n",-1.0);
    }
  } else {
    sprintf(lbuf,"Cavity Calculation Error\n");
    CavPlotComment(lbuf);
  }
  fflush(l_log);
  fprintf(l_log,"$ CavAtom\n");
  used();
  fflush(l_log);
  fprintf(l_log,"$ PlotAtom\n");
  for(i=0;i<nPlt;i++){
    int k;
    k=iPlt[i];
    fprintf(l_log,"%-6s%4d%10.5f%10.5f%10.5f%10.5f\n",natm[k],iTbl[k],
	    xyz[k][0],xyz[k][1],xyz[k][2],w[k]);
  }
  fflush(l_log);
  fprintf(l_log,"$ CavBond\n");
  for(i=0;i<nBond;i++){
    double *sxyz,*exyz;
    sxyz=xyz[iPs[i]];
    exyz=xyz[iPe[i]];
    fprintf(l_log,"%-6s %10.5f%10.5f%10.5f %-6s %10.5f%10.5f%10.5f \n",
	    natm[iPs[i]],sxyz[0],sxyz[1],sxyz[2],
	    natm[iPe[i]],exyz[0],exyz[1],exyz[2]);
  }
  fprintf(l_log,"$ End\n");
  fflush(l_log);
  CavClosePlotter();
  fclose(l_log);
  return 1;
}
